@@ -21,8 +21,8 @@ from PyQt5.QtCore import QSettings, QVariant, Qt, QEvent
 from PyQt5.Qt import pyqtSlot, pyqtSignal
 from stdcomqt5 import *
 from opcua import ua, Server, uamethod
-from opcua.common.callback import CallbackType
-import copy
+#from opcua.common.callback import CallbackType
+#import copy
 
 
 class Tree (object) :
@@ -65,16 +65,6 @@ class Tree (object) :
                     self.cb(key[0], name, name, data )
 
 
-class VSetting(QSettings):
-    """
-    Used to save setup data
-    """
-    def __init__(self, project : str = "stec-opcua"):
-        """
-        :param project:   default is "stec-opc"
-        """
-        super().__init__( project, QSettings.IniFormat)
-
 class SubHandler(object):
     """
     Subscription Handler. To receive events from server for a subscription
@@ -379,12 +369,13 @@ class StecMultiverseOPCUA(QDialog):
         itm4 = QTableWidgetItem()
         itm4.setText(str(freq))
 
-        bxt1 = QCheckBox(enabled)
-        if enabled.upper() == "TRUE" :
+
+        bxt1 = QCheckBox( str(enabled))
+        if str(enabled).upper() == "TRUE" :
             bxt1.setChecked(True)
 
-        bxt2 =  QCheckBox(readonly)
-        if readonly.upper() == "TRUE":
+        bxt2 =  QCheckBox(str(readonly))
+        if str(readonly).upper() == "TRUE":
             bxt2.setChecked(True)
 
         self.ui.tableWidgetAllowable.setItem(rows, 0, itm1)
@@ -494,7 +485,7 @@ class StecMultiverseOPCUA(QDialog):
         """
 
         self.RebuildAllowed()
-        settings = VSetting()
+        settings = VSettings()
 
         self.MultiverseHostname = self.ui.lineEditMultiverseHost.text()
         self.MultiversePort = int(self.ui.lineEditMultiversePort.text())
@@ -521,7 +512,7 @@ class StecMultiverseOPCUA(QDialog):
         loads all configurations
         :return:
         """
-        settings = VSetting()
+        settings = VSettings()
         self.MultiverseHostname = str(settings.value("MultiverseHostname", self.MultiverseHostname))
         self.MultiversePort = int(settings.value("MultiversePort", self.MultiversePort))
         self.OPCUAEndpoint =  str(settings.value("Endpoint", self.OPCUAEndpoint))
@@ -559,9 +550,11 @@ class StecMultiverseOPCUA(QDialog):
 
 
 if __name__ == "__main__":
-
+    """
+    bumped version
+    """
     if "--version" in sys.argv:
-        print("1.2.0")
+        print("1.2.3")
         sys.exit()
 
     show = True
